/***********************************************************
 * $Id: FieldAccessor.java 4 2006-12-26 19:16:57Z wglas $
 * 
 * Utility classes of the clazzes.org project
 * http://www.clazzes.org
 *
 * Created: 2006-03-13
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 * 
 ***********************************************************/

package org.clazzes.util.sec;

/**
 * The Plain text (pseudo) hasher
 */
public class PlainPasswordHasher implements PasswordHasher
{

	protected final String algo_prefix;

	public PlainPasswordHasher()
	{
		super();
		this.algo_prefix = "{" + getAlgorithmName() + "}";
	}

	/* (non-Javadoc)
	 * @see org.clazzes.util.sec.PasswordHasher#hashPassword(java.lang.String)
	 */
	public String hashPassword(String cleartext)
	{
		return hashPassword(cleartext, HashTools.randomSalt());
	}

	/* (non-Javadoc)
	 * @see org.clazzes.util.sec.PasswordHasher#hashPassword(java.lang.String, java.lang.String)
	 */
	public String hashPassword(String cleartext, String salt)
	{
		return this.algo_prefix + cleartext;
	}

	/* (non-Javadoc)
	 * @see org.clazzes.util.sec.PasswordHasher#checkPassword(java.lang.String, java.lang.String)
	 */
	public boolean checkPassword(String cleartext, String hashed)
	{
		return cleartext.equals(stripAlgorithmKey(hashed));
	}

	/* (non-Javadoc)
	 * @see org.clazzes.util.sec.PasswordHasher#getAlgorithmName()
	 */
	public String getAlgorithmName()
	{
		return "PLAIN";
	}

	public String getAlgorithmPrefix()
	{
		return this.algo_prefix;
	}

	/**
	 * @param from_password
	 * @return The given hashed password without eventual leading "{algo_key}"
	 */
	protected String stripAlgorithmKey(String from_password)
	{
		if (from_password == null)
			return null;
		if (from_password.startsWith(this.algo_prefix))
		{
			String s = from_password.substring(this.algo_prefix.length());
			return s;
		}
		return from_password;
	}

	/**
	 * @param from_password
	 * @return The given hashed password with an eventual missing "{algo_key}"
	 *         prefix
	 */
	protected String prependAlgorithmKey(String to_password)
	{
		if (to_password == null)
			return null;
		if (to_password.startsWith(this.algo_prefix))
			return to_password;
		return this.algo_prefix + to_password;

	}

    /* (non-Javadoc)
     * @see org.clazzes.util.sec.PasswordHasher#getDefaultSaltLength()
     */
    public int getSaltLength() {
        return 0;
    }

}
